@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.14 2004/03/24 02:26:51 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.15 2004/03/24 12:27:04 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -112,8 +112,10 @@ void do_child(int unix_fd, int inet_fd)
 			continue;
 		}
 
+		major = ntohl(sp->protoVersion) >> 16;
+		pool_debug("major: %d", major);
+
 		/* V3(7.4 or later) protocol? */
-		major = sp->protoVersion >> 16;
 		if (major < 1234 && major > 2)
 		{
 			static char *msg = "Sorry, we do not support V3 protocol";
@@ -160,7 +162,7 @@ void do_child(int unix_fd, int inet_fd)
 
 			if (pool_write_and_flush(con, cp, sizeof(CancelPacket)) < 0)
 				pool_error("Could not send cancel request packet");
-
+			pool_close(con);
 			continue;
 		}
 
