@@ -1,11 +1,11 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.8 2004/02/28 14:06:22 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.10 2004/03/24 02:26:51 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003	Tatsuo Ishii
+ * Copyright (c) 2003, 2004	Tatsuo Ishii
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -41,9 +41,6 @@
 
 POOL_CONNECTION_POOL *pool_connection_pool;	/* connection pool */
 
-static  int connect_unix_domain_socket(POOL_CONNECTION_POOL *p);
-static  int connect_inet_domain_socket(POOL_CONNECTION_POOL *p);
-
 /*
 * initialize connection pool
 */
@@ -254,7 +251,7 @@ RETSIGTYPE pool_backend_timer_handler(int sig)
 	}
 }
 
-static  int connect_inet_domain_socket(POOL_CONNECTION_POOL *p)
+int connect_inet_domain_socket(POOL_CONNECTION_POOL *p)
 {
 	int fd;
 	int len;
@@ -305,7 +302,7 @@ static  int connect_inet_domain_socket(POOL_CONNECTION_POOL *p)
 	return fd;
 }
 
-static  int connect_unix_domain_socket(POOL_CONNECTION_POOL *p)
+int connect_unix_domain_socket(POOL_CONNECTION_POOL *p)
 {
 	struct sockaddr_un addr;
 	int fd;
@@ -329,7 +326,7 @@ static  int connect_unix_domain_socket(POOL_CONNECTION_POOL *p)
 
 	if (connect(fd, (struct sockaddr *)&addr, len) < 0)
 	{
-		pool_error("connect_unix_domain_socket: connect() failed: %s",strerror(errno));
+		pool_error("connect_unix_domain_socket: connect() failed: %s", strerror(errno));
 		close(fd);
 		return -1;
 	}
